<?php

namespace HS\Domain\Documents\VirusScan;

use Illuminate\Http\Client\ConnectionException;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class VirusScanner
{
    /**
     * @var string
     */
    protected $apiKey;

    /**
     * @param $apiKey
     */
    public function __construct($apiKey)
    {
        $this->apiKey = $apiKey;
    }

    public function scanContent($content)
    {
        return $this->doScan(md5($content));
    }

    public function scanFile($filePath)
    {
        if (file_exists($filePath)) {
            return $this->doScan(md5_file($filePath));
        }

        Log::error(new \Exception('Could not scan file, temp file not found '.$filePath));

        // Trust, if we cannot determine status
        return ScanResult::clean();
    }

    public function doScan($md5)
    {
        // TODO: Ability to switch scan driver. For
        //       now we'll hard-code the class
        //       See: config('services.virus_scanner.driver')
        return (new Opswat($this->apiKey))->scan($md5);
        // return (new VirusTotal($this->apiKey))->scan($md5);
    }

    protected function determineIsClean($data)
    {
        return (
            empty($data[0]['attributes']['popular_threat_classification'] ?? []) // Has no threat classification
            &&
            ($data[0]['attributes']['last_analysis_stats']['malicious'] ?? 0 ) == 0 // Analysis shows not malicious
        );
    }
}
